#                                               29 December 2006.  SMS.
#
#    BZIP2 1.0 for VMS - MMS Dependency Description File.
#
#    MMS /EXTENDED_SYNTAX description file to generate a C source
#    dependencies file.  Unsightly errors result when /EXTENDED_SYNTAX
#    is not specified.  Typical usage:
#
#    $ MMS /EXTEND /DESCRIP = [.vms]descrip_mkdeps.mms /SKIP
#
# Note that this description file must be used from the main
# distribution directory, not from the [.VMS] subdirectory.
#
# This description file uses these command procedures:
#
#    [.VMS]COLLECT_DEPS.COM
#    [.VMS]MOD_DEP.COM
#
# MMK users without MMS will be unable to generate the dependencies file
# using this description file, however there should be one supplied in
# the kit.  If this file has been deleted, users in this predicament
# will need to recover it from the original distribution kit.
#
# Note:  This dependency generation scheme assumes that the dependencies
# do not depend on host architecture type or other such variables. 
# Therefore, no "#include" directive in the C source itself should be
# conditional on such variables.
#

# Required command procedures.

COMS = [.VMS]COLLECT_DEPS.COM [.VMS]MOD_DEP.COM

# Include the source file lists (among other data).

INCL_DESCRIP_SRC = 1
.INCLUDE [.VMS]DESCRIP_SRC.MMS

# The ultimate product, a comprehensive dependency list.

DEPS_FILE = [.VMS]DESCRIP_DEPS.MMS

# Detect valid qualifier and/or macro options.

.IF $(FINDSTRING Skip, $(MMSQUALIFIERS)) .eq Skip
DELETE_MMSD = 1
.ELSIF NOSKIP
PURGE_MMSD = 1
.ELSE
UNK_MMSD = 1
.ENDIF

# Dependency suffixes and rules.
#
# .FIRST is assumed to be used already, so the MMS qualifier/macro check
# is included in each rule (one way or another).

.SUFFIXES_BEFORE .C .MMSD

.C.MMSD :
.IF UNK_MMSD
	@ write sys$output -
 "   /SKIP_INTERMEDIATES is expected on the MMS command line."
	@ write sys$output -
 "   For normal behavior (delete .MMSD files), specify ""/SKIP""."
	@ write sys$output -
 "   To retain the .MMSD files, specify ""/MACRO = NOSKIP=1""."
	@ exit %x00000004
.ENDIF
	$(CC) $(CFLAGS_INCL) $(MMS$SOURCE) /NOLIST /NOOBJECT -
	 /MMS_DEPENDENCIES = (FILE = $(MMS$TARGET), NOSYSTEM_INCLUDE_FILES)

# List of MMS dependency files.

# In case it's not obvious...
# To extract module name lists from object library module=object lists:
# 1.  Transform "module=[.dest]name.OBJ" into "module=[.dest] name".
# 2.  For [.VMS], add [.VMS] to name.
# 3.  Delete "*]" words.
#
# A similar scheme works for executable lists.

MODS_LIB_BZ2_N = $(FILTER-OUT *], \
 $(PATSUBST *]*.OBJ, *] *, $(MODS_OBJS_LIB_BZ2_N)))

MODS_LIB_BZ2_V = $(FILTER-OUT *], \
 $(PATSUBST *]*.OBJ, *] [.VMS]*, $(MODS_OBJS_LIB_BZ2_V)))

MODS_LIB_BZ2_NS_N = $(FILTER-OUT *], \
 $(PATSUBST *]*.OBJ, *] *, $(MODS_OBJS_LIB_BZ2_NS_N)))

MODS_BZIP2 = $(FILTER-OUT *], \
 $(PATSUBST *]*.EXE, *] *, $(BZIP2)))

MODS_BZIPUTILS = $(FILTER-OUT *], \
 $(PATSUBST *]*.EXE, *] *, $(BZIPUTILS)))

# Complete list of C object dependency file names.

DEPS = $(FOREACH NAME, \
 $(MODS_LIB_BZ2_N) $(MODS_LIB_BZ2_V) $(MODS_LIB_BZ2_NS_N) \
 $(MODS_BZIP2) $(MODS_BZIPUTILS), \
 $(NAME).MMSD)

# Default target is the comprehensive dependency list.

$(DEPS_FILE) : $(DEPS) $(COMS)
.IF UNK_MMSD
	@ write sys$output -
 "   /SKIP_INTERMEDIATES is expected on the MMS command line."
	@ write sys$output -
 "   For normal behavior (delete individual .MMSD files), specify ""/SKIP""."
	@ write sys$output -
 "   To retain the individual .MMSD files, specify ""/MACRO = NOSKIP=1""."
	@ exit %x00000004
.ENDIF
#
#       Note that the space in P3, which prevents immediate macro
#       expansion, is removed by COLLECT_DEPS.COM.
#
        @[.VMS]COLLECT_DEPS.COM "BZIP2" -
         "$(MMS$TARGET)" "[...]*.MMSD" "[.$ (DEST)]" $(MMSDESCRIPTION_FILE)
        @ write sys$output -
         "Created a new dependency file: $(MMS$TARGET)"
.IF DELETE_MMSD
	@ write sys$output -
         "Deleting intermediate .MMSD files..."
	delete /log *.MMSD;*, [.VMS]*.MMSD;*
.ELSE
	@ write sys$output -
         "Purging intermediate .MMSD files..."
	purge /log *.MMSD, [.VMS]*.MMSD
.ENDIF

# CLEAN target.

CLEAN :
	if (f$search( "*.MMSD;*") .nes. "") then -
	 delete /log *.MMSD;*
	if (f$search( "[-.VMS]*.MMSD;*") .nes. "") then -
	 delete /log [-.VMS]*.MMSD;*
	if (f$search( "$(DEPS_FILE);*") .nes. "") then -
	 delete /log $(DEPS_FILE);*

# PURGE target.

PURGE :
	if (f$search( "*.MMSD;*") .nes. "") then -
	 purge /log *.MMSD;*
	if (f$search( "[-.VMS]*.MMSD;*") .nes. "") then -
	 purge /log [-.VMS]*.MMSD;*
	if (f$search( "$(DEPS_FILE);*") .nes. "") then -
	 purge /log $(DEPS_FILE);*

# Explicit dependencies and rules for utility variant modules.
#
# The extra dependency on the normal dependency file obviates including
# the /SKIP warning code in each rule here.

BLOCKSORT_.MMSD : BLOCKSORT.C BLOCKSORT.MMSD
	$(CC) $(CFLAGS_INCL) /define = BZ_NO_STDIO=1 $(MMS$SOURCE) -
	 /NOLIST /NOOBJECT -
	 /MMS_DEPENDENCIES = (FILE = $(MMS$TARGET), NOSYSTEM_INCLUDE_FILES)
	@[.VMS]MOD_DEP.COM $(MMS$TARGET) $(MMS$TARGET_NAME).OBJ $(MMS$TARGET)

BZLIB_.MMSD : BZLIB.C BZLIB.MMSD
	$(CC) $(CFLAGS_INCL) /define = BZ_NO_STDIO=1 $(MMS$SOURCE) -
	 /NOLIST /NOOBJECT -
	 /MMS_DEPENDENCIES = (FILE = $(MMS$TARGET), NOSYSTEM_INCLUDE_FILES)
	@[.VMS]MOD_DEP.COM $(MMS$TARGET) $(MMS$TARGET_NAME).OBJ $(MMS$TARGET)

COMPRESS_.MMSD : COMPRESS.C COMPRESS.MMSD
	$(CC) $(CFLAGS_INCL) /define = BZ_NO_STDIO=1 $(MMS$SOURCE) -
	 /NOLIST /NOOBJECT -
	 /MMS_DEPENDENCIES = (FILE = $(MMS$TARGET), NOSYSTEM_INCLUDE_FILES)
	@[.VMS]MOD_DEP.COM $(MMS$TARGET) $(MMS$TARGET_NAME).OBJ $(MMS$TARGET)

CRCTABLE_.MMSD : CRCTABLE.C CRCTABLE.MMSD
	$(CC) $(CFLAGS_INCL) /define = BZ_NO_STDIO=1 $(MMS$SOURCE) -
	 /NOLIST /NOOBJECT -
	 /MMS_DEPENDENCIES = (FILE = $(MMS$TARGET), NOSYSTEM_INCLUDE_FILES)
	@[.VMS]MOD_DEP.COM $(MMS$TARGET) $(MMS$TARGET_NAME).OBJ $(MMS$TARGET)

DECOMPRESS_.MMSD : DECOMPRESS.C DECOMPRESS.MMSD
	$(CC) $(CFLAGS_INCL) /define = BZ_NO_STDIO=1 $(MMS$SOURCE) -
	 /NOLIST /NOOBJECT -
	 /MMS_DEPENDENCIES = (FILE = $(MMS$TARGET), NOSYSTEM_INCLUDE_FILES)
	@[.VMS]MOD_DEP.COM $(MMS$TARGET) $(MMS$TARGET_NAME).OBJ $(MMS$TARGET)

HUFFMAN_.MMSD : HUFFMAN.C HUFFMAN.MMSD
	$(CC) $(CFLAGS_INCL) /define = BZ_NO_STDIO=1 $(MMS$SOURCE) -
	 /NOLIST /NOOBJECT -
	 /MMS_DEPENDENCIES = (FILE = $(MMS$TARGET), NOSYSTEM_INCLUDE_FILES)
	@[.VMS]MOD_DEP.COM $(MMS$TARGET) $(MMS$TARGET_NAME).OBJ $(MMS$TARGET)

RANDTABLE_.MMSD : RANDTABLE.C RANDTABLE.MMSD
	$(CC) $(CFLAGS_INCL) /define = BZ_NO_STDIO=1 $(MMS$SOURCE) -
	 /NOLIST /NOOBJECT -
	 /MMS_DEPENDENCIES = (FILE = $(MMS$TARGET), NOSYSTEM_INCLUDE_FILES)
	@[.VMS]MOD_DEP.COM $(MMS$TARGET) $(MMS$TARGET_NAME).OBJ $(MMS$TARGET)

